#!/bin/bash
# program to use apple script as part of install
# to close all browsers and MySpeed
#
# Also removes the older verison of diagnostics, if it is there
# and moves MySpeed out of the trash if it happens to be there
#

thisProgramName="removeMySpeed.tool"

# routine to check for failure, print a message and exit
checkForFailure()
{
	if [ -z "$1" ] || [ -z "$2" ]; then
		echo "Error...syntax: checkForFailure <last Error code> <error message>"
		exit 0
	else
		if [ $1 != "0" ]; then
			echo $2
			echo "$thisProgramName failed.."
			exit -1
		fi
	fi
}

# function runs all the applscript
#
runAppleScript()
{
    # we put all the applescript into a long
    # string and then just pipe that to osascript
    #
    osaCommand=`cat <<EOF
        on ApplicationIsRunning(appName)
            tell application "System Events" to set appNameIsRunning to exists (processes where name is appName)
            return appNameIsRunning
        end ApplicationIsRunning

        on QuitApplication(appName, appleScriptName)
            if ApplicationIsRunning(appName) then
                tell application appleScriptName 
                    quit 
                end tell
            end if
        end QuitApplication

        set os_version to do shell script "sw_vers -productVersion"	
        set dialogApp to "Finder"

        if (ApplicationIsRunning("MySpeed") or ApplicationIsRunning("MySpeedInjector") or ¬
            ApplicationIsRunning("MySpeedDiagnostics") or ¬
            ApplicationIsRunning("Safari") or ApplicationIsRunning("firefox-bin") or ¬
            ApplicationIsRunning("firefox") or ¬
            ApplicationIsRunning("Google Chrome") or ApplicationIsRunning("Opera") or ¬
            ApplicationIsRunning("flock-bin") or ApplicationIsRunning("Camino") or ¬
            ApplicationIsRunning("RockMelt") or ¬
            ApplicationIsRunning("Google Chrome Canary") or ¬ 
            ApplicationIsRunning("RealPlayer") or ApplicationIsRunning("mdm_flash_player")) then
            tell application dialogApp
                activate
                set msg to "In order to continue, MySpeed Installer needs to close browsers and other MySpeed enabled applications.."
                display dialog msg default button 1 buttons {"Continue"} with title "MySpeed Installer"
            end tell
        end if	
    
        QuitApplication("MySpeedInjector", "MySpeedInjector")
        QuitApplication("MySpeed", "MySpeed")
        QuitApplication("MySpeedDiagnostics", "MySpeedDiagnostics")
        QuitApplication("Safari","Safari")
        QuitApplication("firefox-bin", "firefox")
        QuitApplication("firefox", "firefox")
        QuitApplication("Google Chrome", "Google Chrome")
        QuitApplication("Opera", "Opera")
        QuitApplication("flock-bin", "flock")
        QuitApplication("Camino", "Camino")
        QuitApplication("RockMelt", "RockMelt")
        QuitApplication("Google Chrome Canary", "Google Chrome Canary")
        QuitApplication("RealPlayer", "RealPlayer")
        QuitApplication("mdm_flash_player", "Wimpy FLV Player")

        delay 1

        if ApplicationIsRunning("MySpeed") then
            tell application dialogApp
                activate
                set msg to "MySpeed is still running..please close now or restart MySpeed after install is completed.."
                display dialog msg default button 1 buttons {"Continue"} with title "MySpeed Installer"
            end tell
    
        end if
EOF
`
    echo "$osaCommand" | osascript
}

# first run the applescript to close everything
runAppleScript

# get sudo password
# clear out the old sudo password
sudo -k
read -s -p "Enter password to remove all MySpeed components: " sudoPassword
echo ""
checkForFailure $? "Failed to get needed password...cannot continue"
# test the password
echo "testing password"
echo $sudoPassword | sudo -S pwd
checkForFailure $? "sudo passord incorrect..."

# For old installs, need to remove user local copies of some files
# Enounce, Inc, copyright (c) 2010. All rights reserved.
#
# remove the Enounce AUTimePitch Audio Unit
if [ -e /Library/Audio/Plug-Ins/Components/AUTimePitch.component ] 
then 
    echo "Removing AUTimePitch"
    echo $sudoPassword | sudo -S rm -rf /Library/Audio/Plug-Ins/Components/AUTimePitch.component 
fi

# Remove the NPAPI MySpeed Plugin, if it exists
if [ -e /Library/Internet\ Plug-Ins/NPMySpeedPlugin.plugin ] 
then 
    echo "Removing NPMySpeedPlugin"
    echo $sudoPassword | sudo -S rm -rf /Library/Internet\ Plug-Ins/NPMySpeedPlugin.plugin 
fi

# Remove the MySpeed Scripting Addition, if it exists
if [ -e /Library/ScriptingAdditions/MySpeed.osax ] 
then 
    echo "Removing MySpeed.osax"
    echo $sudoPassword | sudo -S rm -rf /Library/ScriptingAdditions/MySpeed.osax 
fi

# Remove MySpeed, if it exists
if [ -e /Applications/MySpeed.app ] 
then 
    echo "Removing MySpeed"
    echo $sudoPassword | sudo -S rm -rf /Applications/MySpeed.app
fi

# Restore Safari Sandbox, if necessary
pathToSafariPrivateSandbox=/System/Library/PrivateFrameworks/WebKit2.framework/WebProcess.app/Contents/Resources/com.apple.WebProcess.sb
pathToSafariPrivateSandboxBackup=/System/Library/PrivateFrameworks/WebKit2.framework/WebProcess.app/Contents/Resources/com.apple.WebProcess.sb.Original
pathToSafariStagedSandbox=/System/Library/StagedFrameworks/Safari/WebKit2.framework/WebProcess.app/Contents/Resources/com.apple.WebProcess.sb
pathToSafariStagedSandboxBackup=/System/Library/StagedFrameworks/Safari/WebKit2.framework/WebProcess.app/Contents/Resources/com.apple.WebProcess.sb.Original

pathToMySpeedSandbox=/Library/Sandbox/Profiles/com.enounce.MySpeed.sb
if [ -e "$pathToSafariPrivateSandboxBackup" ]
then
    echo "Restoring Private Safari Sandox"
    echo $sudoPassword | sudo -S mv -f $pathToSafariPrivateSandboxBackup $pathToSafariPrivateSandbox
fi

if [ -e "$pathToSafariStagedSandboxBackup" ]
then
    echo "Restoring Staged Safari Sandox"
    echo $sudoPassword | sudo -S mv -f $pathToSafariStagedSandboxBackup $pathToSafariStagedSandbox
fi

# Remove MySpeed sandbox, if it exists
if [ -e "$pathToMySpeedSandbox" ]
then
    echo "Removing MySpeed Sandbox"
    echo $sudoPassword | sudo -S rm -rf $pathToMySpeedSandbox
fi

echo "MySpeed has been removed....thank you for trying MySpeed!"
